@@ -1,6 +1,6 @@
 lda.collapsed.gibbs.sampler <-
 function (documents, K, vocab, num.iterations, alpha, eta, initial = NULL, 
-    burnin = NULL, compute.log.likelihood = FALSE) 
+    burnin = NULL, compute.log.likelihood = FALSE, trace = 0L) 
 {
     if (class(vocab) == "list") {
         lengths <- as.integer(sapply(vocab, length))
@@ -13,10 +13,10 @@ function (documents, K, vocab, num.iterations, alpha, eta, initial = NULL,
     retval <- structure(.Call("collapsedGibbsSampler", documents, 
         as.integer(K), lengths, as.integer(num.iterations), as.double(alpha), 
         as.double(eta), NULL, NULL, NULL, NULL, NULL, NULL, NULL, 
-        initial, as.integer(burnin), as.logical(compute.log.likelihood)), 
-        names = c("assignments", "topics", "topic_sums", "document_sums", 
-            if (is.null(burnin)) NA else "document_expects", 
-            NA, NA, NA, NA, if (compute.log.likelihood) "log.likelihoods" else NA))
+        initial, as.integer(burnin), as.logical(compute.log.likelihood), 
+        trace), names = c("assignments", "topics", "topic_sums", 
+        "document_sums", if (is.null(burnin)) NA else "document_expects", 
+        NA, NA, NA, NA, if (compute.log.likelihood) "log.likelihoods" else NA))
     colnames(retval$topics) <- all.vocab
     retval
 }
